<?php
/**
 * Rattlesnake functions and definitions
 */

if ( ! function_exists( 'rattlesnake_support' ) ) {

	// Sets up theme defaults and registers support for various WordPress features.
	function rattlesnake_support() {

		// Add support for block styles.
		add_theme_support( 'wp-block-styles' );

		// Enqueue editor styles.
		add_editor_style( 'style.css' );

	}
}
add_action( 'after_setup_theme', 'rattlesnake_support' );

if ( ! function_exists( 'rattlesnake_styles' ) ) {
	// Enqueue styles.
	function rattlesnake_styles() {

		// Register theme stylesheet.
		wp_register_style(
			'rattlesnake-style',
			get_template_directory_uri() . '/assets/css/theme.min.css',
			array(),
			wp_get_theme()->get( 'Version' )
		);

		// Add styles inline.
		wp_add_inline_style( 'rattlesnake-style', rattlesnake_get_font_face_styles() );

		// Enqueue theme stylesheet.
		wp_enqueue_style( 'rattlesnake-style' );

	}
}
add_action( 'wp_enqueue_scripts', 'rattlesnake_styles' );

if ( ! function_exists( 'rattlesnake_editor_styles' ) ) {
	// Enqueue editor styles.
	function rattlesnake_editor_styles() {
		// Add styles inline.
		wp_add_inline_style( 'wp-block-library', rattlesnake_get_font_face_styles() );

		add_editor_style(
			get_template_directory_uri() . '/assets/css/theme.min.css'
		);
	}
}
add_action( 'admin_init', 'rattlesnake_editor_styles' );

// Get font face styles.
if ( ! function_exists( 'rattlesnake_get_font_face_styles' ) ) {
	function rattlesnake_get_font_face_styles() {
		return "
		@font-face{
			font-family: 'Heebo';
			font-weight: 100;
			font-style: normal;
			font-stretch: normal;
			font-display: swap;
			src: url('" . get_theme_file_uri( 'assets/fonts/Heebo-VariableFont_wght.woff2' ) . "') format('woff2');
		}
		@font-face{
			font-family: 'Heebo';
			font-weight: 200;
			font-style: normal;
			font-stretch: normal;
			font-display: swap;
			src: url('" . get_theme_file_uri( 'assets/fonts/Heebo-VariableFont_wght.woff2' ) . "') format('woff2');
		}
		@font-face{
			font-family: 'Heebo';
			font-weight: 300;
			font-style: normal;
			font-stretch: normal;
			font-display: swap;
			src: url('" . get_theme_file_uri( 'assets/fonts/Heebo-VariableFont_wght.woff2' ) . "') format('woff2');
		}
		@font-face{
			font-family: 'Heebo';
			font-weight: 400;
			font-style: normal;
			font-stretch: normal;
			font-display: swap;
			src: url('" . get_theme_file_uri( 'assets/fonts/Heebo-VariableFont_wght.woff2' ) . "') format('woff2');
		}
		@font-face{
			font-family: 'Heebo';
			font-weight: 500;
			font-style: normal;
			font-stretch: normal;
			font-display: swap;
			src: url('" . get_theme_file_uri( 'assets/fonts/Heebo-VariableFont_wght.woff2' ) . "') format('woff2');
		}
		@font-face{
			font-family: 'Heebo';
			font-weight: 600;
			font-style: normal;
			font-stretch: normal;
			font-display: swap;
			src: url('" . get_theme_file_uri( 'assets/fonts/Heebo-VariableFont_wght.woff2' ) . "') format('woff2');
		}
		@font-face{
			font-family: 'Heebo';
			font-weight: 700;
			font-style: normal;
			font-stretch: normal;
			font-display: swap;
			src: url('" . get_theme_file_uri( 'assets/fonts/Heebo-VariableFont_wght.woff2' ) . "') format('woff2');
		}
		@font-face{
			font-family: 'Heebo';
			font-weight: 800;
			font-style: normal;
			font-stretch: normal;
			font-display: swap;
			src: url('" . get_theme_file_uri( 'assets/fonts/Heebo-VariableFont_wght.woff2' ) . "') format('woff2');
		}
		@font-face{
			font-family: 'Heebo';
			font-weight: 900;
			font-style: normal;
			font-stretch: normal;
			font-display: swap;
			src: url('" . get_theme_file_uri( 'assets/fonts/Heebo-VariableFont_wght.woff2' ) . "') format('woff2');
		}
		";
	}
}

// Add script to Editor
if ( ! function_exists( 'rattlesnake_admin_add_scripts' ) ) {
	function rattlesnake_admin_add_scripts( $hook ){
		if ( 'appearance_page_rattlesnake' != $hook ) {
			return;
		}
		
		wp_register_style( 'rattlesnake-settings-css',  get_template_directory_uri() . '/assets/css/admin.min.css' , '1.0.0' );
		wp_enqueue_style( 'rattlesnake-settings-css');
	
	}
}
add_action( 'admin_enqueue_scripts', 'rattlesnake_admin_add_scripts');

// Add admin page content
get_template_part( 'inc/theme' );

// Add admin page
if ( ! function_exists( 'rattlesnake_create_menu' ) ) {
	add_action( 'admin_menu', 'rattlesnake_create_menu' );
	// Adds our dashboard menu item
	function rattlesnake_create_menu() {
		add_theme_page( 'Rattlesnake WordPress Theme', 'Rattlesnake', 'edit_theme_options', 'rattlesnake', 'rattlesnake_admin_theme_page' );
	}
}